Mellanox RHEL-OSP plugin
=======================

Mellanox RHEL-OSP plugin overview
------------------------


The Mellanox Redhat Openstack plugin is a bundle of scripts, packages
and metadata that will extend Red Hat Openstack and add Mellanox
features such as SR-IOV for networking and iSER protocol for storage.
Red Hat Openstack can configure Mellanox ConnectX-4 network
adapters to accelerate the performance of compute and storage traffic.
This implements the following performance enhancements:

Compute nodes network enhancements:
*   SR-IOV based networking
*   VXLAN traffic offload
*   Cinder nodes use iSER block storage as the iSCSI transport
 rather than the default iSCSI over TCP.
*   Active-Backup Bonding over Mellanox interface.

These features reduce CPU overhead, boost throughput, reduce
latency, and enable network traffic to bypass the software
switch layer (e.g. Open vSwitch).

Mellanox plugin integration with Mellanox NEO Network managment
platform enables switch VLAN auto provisioning and
port configuration for Ethernet networks over private VLAN networks.


Developer's specification
-------------------------

Please refer to:
[The Product Documentation](<http://www.mellanox.com/page/products_dyn?product_family=273&mtag=cloudx_software>)

Requirements
------------

| Requirement                      | Version/Comment |
|----------------------------------|-----------------|
| Red Hat Director compatibility |  10.0            |

The Mellanox ConnectX-4 adapters family supports up to 100 Gb/s. To
reach 100 Gb/s speed in your
network with ConnectX-4 adapters, you must use Mellanox Ethernet
switches supporting
100 Gb (e.g. SN2700 (ETH), SB7700 (IB)). The switch ports should be
configured specifically to use 100 Gb speed. No additional
configuration is required on the adapter side.

Mellanox plugin configuration
=============================

For detailed setup configuration of Ethernet, please refer to Mellanox
plugin configuration section in
[The Product Documentation](<http://www.mellanox.com/page/products_dyn?product_family=273&mtag=cloudx_software>)

Installation Guide
==================

To install Mellanox plugin, follow these steps:

1. Install Red Hat undercloud, please follow these steps:
    1. Install the Undercloud VM operating system.
    2. Register the system.
    3. Install the undercloud packages.
    4. Configure the undercloud:
       * Obtain and upload overcloud images.
       * Register ironic nodes.
       * Inspect the hardware of the nodes (run introspection).
       * Download ironic-inspector data to swift-data directory and define
root disk for the nodes.
       * Tag node's profiles, root disks and install the swift data
to a swift data directory.
       * For more information, please see
[Red Hat Director 10.0 documentation](<https://access.redhat.com/documentation/en/red-hat-openstack-platform/10/single/director-installation-and-usage/>).



2. Download the plugin tar.gz file for Red Hat Director 10 from
[The Product Web Page](<http://www.mellanox.com/page/products_dyn?product_family=273&mtag=cloudx_software>)

3. Installing the plugin:
    ```
    # tar -zxvf mellanox-rhel-osp-2.0.0.tar.gz  -C <stack homedir>
    ```
    The mellanox-rhel-osp folder will be extracted under the HOME directory.
4. Check available interfaces and their drivers of all registered ironic nodes
(run it inside deployment_sources/summarize_interfaces.py ):
   ```
    # python summarize_interfaces.py --help
    usage: summarize_interfaces.py [-h] --path_to_swift_data PATH_TO_SWIFT_DATA

    log file: ./mellanox-rhel-osp.log

    optional arguments:
      -h, --help            show this help message and exit
      --path_to_swift_data PATH_TO_SWIFT_DATA Path to swift-data directory
   ```

   **Note:** This step is crucial for summarizing the interfaces
   names and their drivers.


5. Edit the config.yaml file with the parameters and flavors required to create
the env template
file (deployment_sources/environment_conf/config.yaml). This is the main file
to configure before deploying TripleO over Mellanox NICs. After
configuring this file, TripleO basic configurations file will be generated in
this directory.
 You can use this file or further customize it before starting the deployment.
    ```
    Sriov:
    sriov_enable: true
    number_of_vfs: 16
    sriov_interface: 'enp3s0f0'

    Neutron:
    physnet_vlan: 'default_physnet'
    physnet_vlan_range: '21:36'
    network_type: 'vlan'

    Iser:
    iser_enable: true
    storage_network_port: 'enp3s0f1'

    # Neo is set to false by default as it is not supported in this version.

    Neo:
    neo_enable: false
    neo_ip:
    neo_username: 'admin'
    neo_password: 123456
    InterfacesValidation: true

    Bond:
    bond_enable: true
    InterfacesValidation: false
    ```

    **Note:** An example of the config.yaml file is available under<stack homedir>/mellanox-rhel-osp/deployment_sources/environment_conf/.

6.  Generate environment yaml file to be used in the overcloud deployment
command, as in the example under deploy.sh
(run it inside deployment_sources/):
    ```
    ./create_conf_template.py -h
    usage: create_conf_template.py [-h]

    Available features to choose:
        - SRIOV
        - iSER
        - Neutron
        - Bonding

    Choose the required configurations in config.yaml

    optional arguments:
      -h, --help  show this help message and exit
    ```
7.  Modify the deployment_sources/network/network_env.yaml to match
your environment network settings and new names used in
interfaces_drivers yaml file if added. Example:
    ```
    Parameter_defaults:
    # Reguired parameters
    ProvisioningInterface: eno1
    ExternalInterface: eno2
    StorageInterface: enp3s0f0
    TenantInterface: enp3s0f1
    NeutronExternalNetworkBridge: "br-ex"
    # Just provide the cider for the required networks
    #(Here are TenantNetCidr, StorageNetCidr, ExternalNetCidr)
    TenantNetCidr: 172.17.0.0/24
    StorageNetCidr: 172.18.0.0/24
    ExternalNetCidr:  <external_net_cidr>
    #InternalApiNetCidr: 172.16.0.0/24
    #StorageMgmtNetCidr: 172.19.0.0/24
    #ManagementNetCidr: 172.20.0.0/24

    # Just provide the Allocation pools for required networks
    TenantAllocationPools: [{'start': '172.17.0.10', 'end': '172.17.0.200'}]
    StorageAllocationPools: [{'start': '172.18.0.10', 'end': '172.18.0.200'}]
    ExternalAllocationPools: [{'start': '<external_ip_range_start>', 'end': '<external_ip_range_end>'}]
    #StorageMgmtAllocationPools: [{'start': '172.19.0.10', 'end': '172.19.0.200'}]
    #ManagementAllocationPools: [{'start': '172.20.0.10', 'end': '172.20.0.200'}]
    #InternalApiAllocationPools: [{'start': '172.16.0.10', 'end': '172.16.0.200'}]
    ExternalInterfaceDefaultRoute: <external_default_gateway>
    # The gateway of the external network
    ControlPlaneDefaultRoute: <undercloud_internal_ip># The internal IP of the undercloud
    EC2MetadataIp: <undercloud_internal_ip> # The internal IP of the undercloud
    DnsServers: ["8.8.8.8","8.8.4.4"]
    NtpServer: <ntp_server>
    ```
If bonding is enabled:
 1. you need to assign required network vlan ID in network_env.yaml:
    ```
    # Use these parameters when using VLANS or Bonding
    #InternalApiNetworkVlanID: 20
    #StorageNetworkVlanID: 30
    #StorageMgmtNetworkVlanID: 40
    #TenantNetworkVlanID: 50
    #ExternalNetworkVlanID: 10
    ```
 2. Customize bonding option in network_env.yaml:
    ```
    # Customize bonding options, e.g. "mode=4 lacp_rate=1 updelay=1000 miimon=100"
    #BondInterfaceOvsOptions: "bond_mode=active-backup"
    ```
8.  Generate the node's network topology for os-net-config based on the chosen
configurations in config.yaml. This script is used to generate <role>.yaml
files under network directory. It is used in network_env.yaml based on neutron
network type in config.yaml vlan/vxlan in the folder:
<stack homedir>/mellanox-rhel-osp/deployment_sources/network.
 (run it inside deployment_sources/)
    ```
    # python create_network_conf.py --help
    usage: create_network_conf.py [-h]

    Available Modes to choose from:
    -------------------------------
        - vlan
        - vxlan

    Set the required environment configurations in config.yaml
    Set the required network configurations in network_env.yaml

    optional argumentas:
    -h, --help  show this help message and exit
    ```


9. Prepare overcloud image: (deployment_sources/prepare_overcloud_image.py)
    ```
    # python prepare_overcloud_image.py --help
    usage: prepare_overcloud_image.py [-h] --iso_ofed_path ISO_OFED_PATH
                                      --overcloud_images_path
                                      OVERCLOUD_IMAGES_PATH --root_password
                                      ROOT_PASSWORD --redhat_account_username
                                      REDHAT_ACCOUNT_USERNAME
                                      --redhat_account_password
                                       REDHAT_ACCOUNT_PASSWORD
                                      [--lldp_package_path LLDP_PACKAGE_PATH]
                                      [--python_mlnx_package_path PYTHON_MLNX_PACKAGE_PATH]

    Log file: ./mellanox-rhel-osp.log

    optional arguments:
    -h, --help            show this help message and exit
    --iso_ofed_path ISO_OFED_PATH path to the OFED iso file
    --overcloud_images_path OVERCLOUD_IMAGES_PATH path to the overcloud images
    --root_password ROOT_PASSWORD  set root password for the overcloud nodes
    --redhat_account_username REDHAT_ACCOUNT_USERNAME
                    username of the Redhat account for registering
    --redhat_account_password REDHAT_ACCOUNT_PASSWORD
                    password of the Redhat account for registering
    [--lldp_package_path LLDP]
                    Optional path to install specific lldpd package
    [--python_mlnx_package_path PYTHON_MLNX_PACKAGE_PATH]
                    Optional path to install specific python-networking-mlnx package
    ```
10. Run the deployment command you want based on your overcloud needs
or run the example deploy  command which can be found inside deploy.sh
script at the deploy directory, after modifying it to use related
environment files that you need.

User Guide
==========

Please read the
[The Product Documentation](<http://www.mellanox.com/page/products_dyn?product_family=273&mtag=cloudx_software>).

Reporting Bugs
==============

Bugs should be reported to support@mellanox.com.

Contributors
============

* David Slama: <dudus@mellanox.com> (PM)
* Aviram Bar-Haim: <aviramb@mellanox.com> (Release manager and Developer)
* Rawan Herzallah: <rawanh@mellanox.com> (Developer)
* Tamara Wari: <tamarasu@mellanox.com> (Developer)
* Hasan Qunoo: <hasanq@mellanox.com> (Verification engineer)
* Waleed Musa: <waleedm@mellanox.com> (Verification engineer)
* Hamdy Khader: <hamdyk@mellanox.com> (Verification engineer)
* Noam Angel: <noama@mellanox.com> (QA engineer)
* Alexander Fridman: <sasha@mellanox.com> (E2E engineer)
* Igor Braginsky: <igorbr@mellanox.com> (E2E engineer)
