#!/usr/bin/env python
# Copyright 2016 Mellanox Technologies, Ltd
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
# implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import os


DEPLOY_SRC_DIR_PATH = os.path.dirname(os.path.abspath(__file__))
PARENT_PKG_PATH = os.path.abspath(os.path.join(DEPLOY_SRC_DIR_PATH, os.pardir))


class EnvParams:

    METADATA_FILE = 'metadata.yaml'
    ENV_CONF_DIR = 'environment_conf'
    DEPLOY_SRC_DIR = 'deployment_sources'
    NETWORK_CONF_DIR = 'network'
    OVC_SCRIPTS_DIR = 'overcloud_scripts'
    SCRIPTS_DIR = 'scripts'
    TMP_FILES_DIR = 'tmp_files'
    FIRSTBOOT_SCRIPT = 'firstboot'

    METADATA_FILE_PATH = os.path.join(PARENT_PKG_PATH, METADATA_FILE)
    ENV_CONF_DIR_PATH = os.path.join(DEPLOY_SRC_DIR_PATH, ENV_CONF_DIR)
    NETWORK_CONF_DIR_PATH = os.path.join(DEPLOY_SRC_DIR_PATH, NETWORK_CONF_DIR)
    OVC_SCRIPTS_DIR_PATH = os.path.join(DEPLOY_SRC_DIR_PATH, OVC_SCRIPTS_DIR)
    SCRIPTS_DIR_PATH = os.path.join(OVC_SCRIPTS_DIR_PATH, SCRIPTS_DIR)
    TMP_FILES_DIR_PATH = os.path.join(DEPLOY_SRC_DIR_PATH, TMP_FILES_DIR)
    FIRSTBOOT_SCRIPT_PATH = os.path.join(TMP_FILES_DIR_PATH, FIRSTBOOT_SCRIPT)

    CONF_FILE_NAME = 'config.yaml'
    NETWORK_CONF_FILE_NAME = 'network_env.yaml'
    COMMON_SCRIPT = 'common'
    RESTART_SERVICE_SCRIPT = 'restart_service.sh'
    LOG_FILE = 'mellanox-rhel-osp.log'
    ENV_YAML_FILE = 'env.yaml'
    ENV_TEMPLATE_YAML_FILE = 'env-template.yaml'
    NEUTRON_SRIOV_YAML_FILE = 'neutron-sriov.yaml'
    NEUTRON_SRIOV_TEMPLATE_YAML_FILE = 'neutron-sriov-template.yaml'
    INTERFACES_DRIVERS_YAML_FILE = 'interfaces_drivers.yaml'

    ENV_YAML_FILE_PATH = os.path.join(ENV_CONF_DIR_PATH, ENV_YAML_FILE)
    ENV_TEMPLATE_YAML_FILE_PATH = os.path.join(ENV_CONF_DIR_PATH,
                                               ENV_TEMPLATE_YAML_FILE)
    NEUTRON_SRIOV_YAML_FILE_PATH = os.path.join(ENV_CONF_DIR_PATH,
                                                NEUTRON_SRIOV_YAML_FILE)
    NEUTRON_SRIOV_TEMPLATE_YAML_FILE_PATH = os.path.join(
                                             ENV_CONF_DIR_PATH,
                                             NEUTRON_SRIOV_TEMPLATE_YAML_FILE)
    INTERFACES_DRIVERS_YAML_FILE_PATH = os.path.join(
        ENV_CONF_DIR_PATH,
        INTERFACES_DRIVERS_YAML_FILE)
    CONF_FILE_PATH = os.path.join(ENV_CONF_DIR_PATH, CONF_FILE_NAME)
    NETWORK_CONF_FILE_PATH = os.path.join(NETWORK_CONF_DIR_PATH,
                                          NETWORK_CONF_FILE_NAME)
    COMMON_SCRIPT_PATH = os.path.join(SCRIPTS_DIR_PATH, COMMON_SCRIPT)
    RESTART_SERVICE_PATH = os.path.join(SCRIPTS_DIR_PATH,
                                        RESTART_SERVICE_SCRIPT)
    LOG_FILE_PATH = os.path.join(DEPLOY_SRC_DIR_PATH, LOG_FILE)

    OVC_FULL_IMAGE_NAME = 'overcloud-full.qcow2'
    MNT_OFED_DIR_PATH = os.path.join('/mnt', 'ofed')
    OFED_VERSION_FILE = '.mlnx'
    OFED_DISTRO_FILE = 'distro'
    OFED_ARCH_FILE = '.arch'
    OFED_VERSION_PATH = os.path.join(MNT_OFED_DIR_PATH, OFED_VERSION_FILE)
    OFED_DISTRO_PATH = os.path.join(MNT_OFED_DIR_PATH, OFED_DISTRO_FILE)
    OFED_ARCH_PATH = os.path.join(MNT_OFED_DIR_PATH, OFED_ARCH_FILE)

    STACKRC_FILE_NAME = 'stackrc'
    STACKRC_FILE_PATH = os.path.join(
        os.path.expanduser('~'), STACKRC_FILE_NAME)

    LIBVIRT_SERVICE = 'libvirtd'


class OvercloudParams:

    OVC_MLNX_PATH = '/opt'
    OFED_DIR = 'ofed'
    OVC_MLNX_SCRIPTS_DIR = 'mlnx_scripts'
    OVC_MLNX_PKGS_DIR = 'mlnx_packages'
    OVC_TARGET_OS_DIR_PATH = '/'
    OVC_TARGET_OS = 'target_os'
    UDEV_RULES_FILE_PATH = '/etc/udev/rules.d/'
    UDEV_RULES_FILE_NAME = '70-persistent-net.rules'
    UDEV_RULE_LINE = 'SUBSYSTEM=="net", ' \
                     'ACTION=="add", ' \
                     'DRIVERS=="?*", ' \
                     'ATTR{address}=="%s", ' \
                     'ATTR{dev_id}=="%s", ' \
                     'ATTR{type}=="1", ' \
                     'KERNEL=="eth*", ' \
                     'NAME="%s"'

    OVC_OFED_DIR_PATH = os.path.join(OVC_MLNX_PATH, OFED_DIR)
    OVC_MLNX_SCRIPTS_DIR_PATH = os.path.join(
        OVC_MLNX_PATH, OVC_MLNX_SCRIPTS_DIR)
    OVC_MLNX_PKGS_DIR_PATH = os.path.join(
        OVC_MLNX_PATH, OVC_MLNX_PKGS_DIR)
    RESTART_SERVICE_PATH = os.path.join(OVC_MLNX_SCRIPTS_DIR_PATH,
                                        EnvParams.RESTART_SERVICE_SCRIPT)
    GRUB_FILE_PATH = os.path.join('/etc', 'default')
    OFED_PREFIX = 'MLNX_OFED_LINUX'
    LLDPD_CONF_FILE_PATH = os.path.join('/etc', 'lldpd.conf')


class PackageParams:

    LLDPD = 'lldpd'
    PYZMQ = 'python-zmq'
    LIBZMQ = 'libzmq3'
    MLNX_REPO_URL = 'http://www.mellanox.com/repository/solutions/' \
                    'openstack/mitaka/redhat/7/'
    MLNX_REPO = 'mellanox.com_repository_solutions_openstack_mitaka_redhat_7_'
    PYTHON_NET_MLNX = 'python-networking-mlnx'
    PYTHON_NET_MLNX_URL = 'https://buildlogs.centos.org/centos/7/cloud/' \
                          'x86_64/rdo-trunk-mitaka-tested/'
    PYTHON_NETWORKING_MLNX_REPO = 'buildlogs.centos.org_centos_7_cloud_' \
                                  'x86_64_rdo-trunk-mitaka-tested_'
